// hd44780_TWI

#ifndef hd44780_TWI_h
#define hd44780_TWI_h

#include "app_util_platform.h"
#include "nrf_drv_twi.h"

/*Pins to connect shield. */
#define TWI_SCL_M		27   //!< Master SCL pin
#define TWI_SDA_M 	26   //!< Master SDA pin

// LCD Type
#define LCD_cols 16
#define LCD_rows 2
#define LCD_addr 0x38

// Enable/Disable TWI Handler
//#define twi_handler_ON

// commands
#define LCD_CLEARDISPLAY 0x01
#define LCD_RETURNHOME 0x02
#define LCD_ENTRYMODESET 0x04
#define LCD_DISPLAYCONTROL 0x08
#define LCD_CURSORSHIFT 0x10
#define LCD_FUNCTIONSET 0x20
#define LCD_SETCGRAMADDR 0x40
#define LCD_SETDDRAMADDR 0x80

// flags for display entry mode
#define LCD_ENTRYRIGHT 0x00
#define LCD_ENTRYLEFT 0x02
#define LCD_ENTRYSHIFTINCREMENT 0x01
#define LCD_ENTRYSHIFTDECREMENT 0x00

// flags for display on/off control
#define LCD_DISPLAYON 0x04
#define LCD_DISPLAYOFF 0x00
#define LCD_CURSORON 0x02
#define LCD_CURSOROFF 0x00
#define LCD_BLINKON 0x01
#define LCD_BLINKOFF 0x00

// flags for display/cursor shift
#define LCD_DISPLAYMOVE 0x08
#define LCD_CURSORMOVE 0x00
#define LCD_MOVERIGHT 0x04
#define LCD_MOVELEFT 0x00

// flags for function set
#define LCD_8BITMODE 0x10
#define LCD_4BITMODE 0x00
#define LCD_2LINE 0x08
#define LCD_1LINE 0x00
#define LCD_5x10DOTS 0x04
#define LCD_5x8DOTS 0x00

// flags for backlight control
#define LCD_BACKLIGHT 0x00
#define LCD_NOBACKLIGHT 0x80

#define En 0x10  // Enable bit
#define Rw 0x20  // Read/Write bit
#define Rs 0x40  // Register select bit

void lcd_init(void);
void lcd_begin(uint8_t cols, uint8_t rows);

/********** high level commands, for the user! */
void clear(void);
void home(void);
void display(void);
void noDisplay(void);
void setCursor(uint8_t, uint8_t);
void noCursor(void);
void cursor(void);
void noBlink(void);
void blink(void);
void scrollDisplayLeft(void);
void scrollDisplayRight(void);
void leftToRight(void);
void rightToLeft(void);
void autoscroll(void);
void noAutoscroll(void);
void createChar(uint8_t, uint8_t[]);
void noBacklight(void);
void backlight(void);

#ifdef twi_handler_ON
void lcd_busy(void);
#endif

/*********** mid level commands, for sending data/cmds */
void write(uint8_t);
void command(uint8_t);
void lcd_print(char*);

/************ low level data pushing commands **********/
void write4bits(uint8_t);
void sendData(uint8_t, uint8_t);
void pulseEnable(uint8_t);


#endif
